<?php defined('BASEPATH') OR exit('No direct script access allowed');

class Sources extends NA_Controller
{
    function __construct()
    {
        parent::__construct();
        $this->load->library('Source', array('NOLOAD' => TRUE));
        $this->load->library('View', array('NOLOAD' => TRUE));
        $this->load->library('Query', array('NOLOAD' => TRUE));
        $this->load->library('Report', array('NOLOAD' => TRUE));
        $this->load->model('Systemstat');
        $this->page = 'sources';

        // Make sure that user is authenticated no matter what page they are on
        if (!$this->ion_auth->logged_in())
        {
            redirect('login');
        }

        $this->data['type'] = 'sid';
    }

    // Basic listing of all the sources available
    public function index()
    {
        $js = array("/js/vizhelpers.js");
        $this->init_page('Sources', 'sources', $js);

        // Reset view id
        $this->reset_view_id();

        $this->load->view('sources/home', $this->data);
    }

    // Create a new source
    public function create()
    {
        // Admin only
        if (!$this->ion_auth->is_admin()) {
            redirect('sources');
        }

        $this->init_page('Create Source', $this->page);

        $this->form_validation->set_rules('source_name', 'Netflow Source Name', 'required'); // Unique
        $this->form_validation->set_rules('ip', 'IP Address', 'required|callback_ipaddress_available');
        $this->form_validation->set_rules('port', 'Listening Port', 'required|callback_port_available'); // Unique
        $this->form_validation->set_rules('flow_type', 'Flow Type', 'required');
        $this->form_validation->set_rules('lifetime', 'Raw Data Lifetime', 'required');
        $this->form_validation->set_rules('lifetime_suffix', 'Lifetime Suffix', 'required');

        if (!$this->data['demo_mode']) {
            if ($this->form_validation->run() === TRUE) {
                $lifetime = $this->input->post('lifetime') . $this->input->post('lifetime_suffix');
                $q = array("name" => $this->input->post('source_name'), 
                           "flowtype" => $this->input->post('flow_type'),
                           "ip" => $this->input->post('ip'),
                           "port" => $this->input->post('port'),
                           "lifetime" => $lifetime);
                try {
                    $s = Source::create($q);
                    $this->load->model('Systemstat');
                    $this->Systemstat->start($s->sid);
                    redirect('sources');
                }
                catch (Exception $e) {
                    $this->data['message'] = $e->getMessage();
                }
            }
        } else {
            $this->data['error'] = "This action is not available in Demo Mode.";
        }

        $this->load->view('sources/create', $this->data);
    }

    // Edit a source
    public function edit($sid)
    {
        // Admin only
        if (!$this->ion_auth->is_admin()) {
            redirect('sources');
        }
        
        $js = array("/js/summary.js", "/js/helpers.js");
        $this->init_page('Edit', $this->page, $js);
        $this->reset_view_id();

        $this->form_validation->set_rules('ip', 'IP Address', 'required');
        $this->form_validation->set_rules('port', 'Listening Port', 'required');
        $this->form_validation->set_rules('lifetime', 'Raw Data Lifetime', 'required');
        $this->form_validation->set_rules('lifetime_suffix', 'Lifetime Suffix', 'required');

        if (!$this->data['demo_mode']) {
            if ($this->form_validation->run() === TRUE) {
                $lifetime = $this->input->post('lifetime') . $this->input->post('lifetime_suffix');
                $s = array("sid" => $sid);
                $q = array("ip" => $this->input->post('ip'),
                           "port" => $this->input->post('port'),
                           "lifetime" => $lifetime);
                try {
                    $source = new Source($sid);
                    $this->Systemstat->stop($sid); // Helps make it remove pid/running process
                    $source->update($q);
                    $this->Systemstat->start($sid);
                    $this->data['message'] = 'Source configuration has been saved!';
                }
                catch (Exception $e) {
                    $this->data['error'] = $e->getMessage();
                }
            }
        } else {
            $this->data['error'] = "This action is not available in Demo Mode.";
        }

        // Get source information
        $this->data['source'] = $this->pull_source($sid);
        $this->data['source']->lifetime_suffix = substr($this->data['source']->lifetime, -1, 1);

        $this->data['tab'] = 'edit';
        $this->data['tabs'] = $this->load->view('sources/tabs', $this->data, true); 
        $this->load->view('sources/edit', $this->data);
    }

    // Display a source
    public function source($sid)
    {
        // Initialize page with source js
        $js = array("/js/summary.js", "/js/helpers.js");
        $this->init_page('Source - Summary', $this->page, $js);
        $this->load_view_id();

        $this->data['source'] = $this->pull_source($sid);

        if ($this->input->get('p')) {
            $p = $this->input->get('p');
            $this->data['selected_bw'] = 1;
            $this->data['bw_start'] = $p['begindate'];
            $this->data['bw_end'] = $p['enddate'];

            // Get the epoch (take off 30 mins on each side)
            $start = strtotime($p['begindate']);
            $end = strtotime($p['enddate']);
            $this->data['bw_start_epoch'] = $start - (60*30);
            $this->data['bw_end_epoch'] = $start + (60*30);
            if ($this->data['bw_end_epoch'] > time()) {
                $this->data['bw_end_epoch'] = time();
            }

        } else {
            $this->data['selected_bw'] = 0;
        }

        $this->data['tab'] = 'summary';
        $this->data['tabs'] = $this->load->view('sources/tabs', $this->data, true); 
        $this->load->view('generic/summary', $this->data);
    }

    // Reports
    public function reports($sid)
    {
        $js = array("/js/reports.js", "/js/summary.js");
        $this->init_page('Reports', $this->page, $js);
        $this->load_view_id();

        $this->data['source'] = $this->pull_source($sid);
        $this->data['cquery'] = grab_request_var('q');
        $this->data['crid'] = grab_request_var('rid', 'null');

        $this->data['tab'] = 'reports';
        $this->data['tabs'] = $this->load->view('sources/tabs', $this->data, true); 
        $this->load->view('generic/reports', $this->data);
    }

    // Queries
    public function queries($sid)
    {
        $js = array("/js/helpers.js", "/js/summary.js", "/js/queries.js");
        $this->init_page('Queries', $this->page, $js);
        $this->load_view_id();
        
        // Setup our source, gets its various information
        $this->data['source'] = $this->pull_source($sid);

        // If there is a query sent here via get - let's get the information
        $this->data['cquery'] = grab_request_var('q');
        $this->data['cqid'] = grab_request_var('qid', 'null');
        
        $this->data['tab'] = 'queries';
        $this->data['tabs'] = $this->load->view('sources/tabs', $this->data, true); 
        $this->load->view('generic/queries', $this->data);
    }

    // Views
    public function views($sid)
    {
        $js = array("/js/helpers.js", "/js/summary.js");
        $this->init_page('Views', $this->page, $js);
        $this->load_view_id();
        
        // Setup our source, gets its various information
        $this->data['source'] = $this->pull_source($sid);

        $this->data['tab'] = 'views';
        $this->data['tabs'] = $this->load->view('sources/tabs', $this->data, true); 
        $this->load->view('sources/views', $this->data);
    }
    
    public function summaryviz($sid)
    {
        $this->data['sid'] = $sid;
        $this->data['vid'] = grab_request_var('vid', NULL);
        $this->data['begindate'] = grab_request_var('begindate', '-30 minutes');
        $this->data['enddate'] = grab_request_var('enddate', '-1 second');
        $this->data['type'] = grab_request_var('type', 'bytes');
        
        $this->load->view('generic/summaryviz', $this->data);
    }
    
    // Return all source information
    private function pull_source($sid)
    {
        // Get source information
        $source = new Source($sid);
        $source->status = $this->Systemstat->source_status($sid);
        return $source;
    }
}
